global: Migrate CONFIG_PCIE_IMX_PERST_GPIO to CFG

Perform a simple rename of CONFIG_PCIE_IMX_PERST_GPIO to CFG_PCIE_IMX_PERST_GPIO

Signed-off-by: Tom Rini <trini@konsulko.com>
diff --git a/include/configs/mx6sabresd.h b/include/configs/mx6sabresd.h
index 2b028e3..116a9c6 100644
--- a/include/configs/mx6sabresd.h
+++ b/include/configs/mx6sabresd.h
@@ -20,7 +20,7 @@
 #define CFG_SYS_FSL_USDHC_NUM	3
 
 #ifdef CONFIG_CMD_PCI
-#define CONFIG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(7, 12)
+#define CFG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(7, 12)
 #define CONFIG_PCIE_IMX_POWER_GPIO	IMX_GPIO_NR(3, 19)
 #endif
 
diff --git a/include/configs/mx6sxsabresd.h b/include/configs/mx6sxsabresd.h
index 8b02c3b..85e5cfb 100644
--- a/include/configs/mx6sxsabresd.h
+++ b/include/configs/mx6sxsabresd.h
@@ -123,7 +123,7 @@
 #endif
 
 #ifdef CONFIG_CMD_PCI
-#define CONFIG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(2, 0)
+#define CFG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(2, 0)
 #define CONFIG_PCIE_IMX_POWER_GPIO	IMX_GPIO_NR(2, 1)
 #endif
 
diff --git a/include/configs/novena.h b/include/configs/novena.h
index dc5b043..6f4353e 100644
--- a/include/configs/novena.h
+++ b/include/configs/novena.h
@@ -41,7 +41,7 @@
 
 /* PCI express */
 #ifdef CONFIG_CMD_PCI
-#define CONFIG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(3, 29)
+#define CFG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(3, 29)
 #define CONFIG_PCIE_IMX_POWER_GPIO	IMX_GPIO_NR(7, 12)
 #endif
 
diff --git a/include/configs/tbs2910.h b/include/configs/tbs2910.h
index 5358597..256331a 100644
--- a/include/configs/tbs2910.h
+++ b/include/configs/tbs2910.h
@@ -22,7 +22,7 @@
 
 /* PCI */
 #ifdef CONFIG_CMD_PCI
-#define CONFIG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(7, 12)
+#define CFG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(7, 12)
 #endif
 
 /* USB */
diff --git a/include/configs/vining_2000.h b/include/configs/vining_2000.h
index 6db68c1..7bfc22c 100644
--- a/include/configs/vining_2000.h
+++ b/include/configs/vining_2000.h
@@ -40,7 +40,7 @@
 #define CFG_MXC_USB_FLAGS   0
 
 #ifdef CONFIG_CMD_PCI
-#define CONFIG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(4, 6)
+#define CFG_PCIE_IMX_PERST_GPIO	IMX_GPIO_NR(4, 6)
 #endif
 
 #define CFG_IMX6_PWM_PER_CLK 66000000
diff --git a/drivers/pci/pcie_imx.c b/drivers/pci/pcie_imx.c
index 46ac017..902507a 100644
--- a/drivers/pci/pcie_imx.c
+++ b/drivers/pci/pcie_imx.c
@@ -566,7 +566,7 @@
 	 * do self-initialisation.
 	 *
 	 * In case your #PERST pin is connected to a plain GPIO pin of the
 	 * CPU, you can define CONFIG_PCIE_IMX_PERST_GPIO in your board's
 	 * configuration file and the condition below will handle the rest
 	 * of the reset toggling.
 	 *
@@ -578,13 +578,13 @@
 	 * Linux at all in the first place since it's in some non-reset
 	 * state due to being previously used in U-Boot.
 	 */
-#ifdef CONFIG_PCIE_IMX_PERST_GPIO
-	gpio_request(CONFIG_PCIE_IMX_PERST_GPIO, "pcie_reset");
-	gpio_direction_output(CONFIG_PCIE_IMX_PERST_GPIO, 0);
+#ifdef CFG_PCIE_IMX_PERST_GPIO
+	gpio_request(CFG_PCIE_IMX_PERST_GPIO, "pcie_reset");
+	gpio_direction_output(CFG_PCIE_IMX_PERST_GPIO, 0);
 	mdelay(20);
-	gpio_set_value(CONFIG_PCIE_IMX_PERST_GPIO, 1);
+	gpio_set_value(CFG_PCIE_IMX_PERST_GPIO, 1);
 	mdelay(20);
-	gpio_free(CONFIG_PCIE_IMX_PERST_GPIO);
+	gpio_free(CFG_PCIE_IMX_PERST_GPIO);
 #else
 	if (dm_gpio_is_valid(gpio)) {
 		/* Assert PERST# for 20ms then de-assert */
@@ -566,7 +566,7 @@
 	 *
 	 * In case your #PERST pin is connected to a plain GPIO pin of the
-	 * CPU, you can define CONFIG_PCIE_IMX_PERST_GPIO in your board's
+	 * CPU, you can define CFG_PCIE_IMX_PERST_GPIO in your board's
 	 * configuration file and the condition below will handle the rest
 	 * of the reset toggling.